@@ -7,10 +7,19 @@ from htmlmin.minify import html_minify
 from django.conf import settings
 
 
+class MarkRequestMiddleware(object):
+    
+    def process_request(self, request):
+        request._hit_htmlmin = True
+
+
 class HtmlMinifyMiddleware(object):
 
     def can_minify_response(self, request, response):
-        req_ok = True
+        try:
+            req_ok = request._hit_htmlmin
+        except AttributeError:
+            return False
 
         if hasattr(settings, 'EXCLUDE_FROM_MINIFYING'):
             for url_pattern in settings.EXCLUDE_FROM_MINIFYING:
